"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudFormationStackProcessor = exports.LOCATION_TYPE = void 0;
const plugin_catalog_backend_1 = require("@backstage/plugin-catalog-backend");
const CloudFormationProcessor_1 = require("../CloudFormationProcessor");
const loadEntities_1 = require("./loadEntities");
const parseTarget_1 = require("./parseTarget");
exports.LOCATION_TYPE = 'aws:cloudformation:stack';
class CloudFormationStackProcessor extends CloudFormationProcessor_1.CloudFormationProcessor {
    constructor(config) {
        super(config);
    }
    getProcessorName() {
        return 'CloudFormationStackProcessor';
    }
    async readLocation(location, _optional, emit) {
        if (location.type !== exports.LOCATION_TYPE) {
            return false;
        }
        try {
            const { arn, region, profile = this.profile } = (0, parseTarget_1.parseTarget)(location.target);
            const entities = await (0, loadEntities_1.loadEntitiesFromCloudFormation)({
                arn,
                region,
                profile
            });
            entities.forEach((entity) => emit(plugin_catalog_backend_1.processingResult.entity(location, entity)));
        }
        catch (e) {
            const message = `${location.type} ${location.target} could not be read, ${e}`;
            emit(plugin_catalog_backend_1.processingResult.generalError(location, message));
        }
        return true;
    }
}
exports.CloudFormationStackProcessor = CloudFormationStackProcessor;
//# sourceMappingURL=CloudFormationStackProcessor.js.map