"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadEntitiesFromCloudFormation = void 0;
const aws_sdk_1 = require("aws-sdk");
const find_and_replace_anything_1 = require("find-and-replace-anything");
const awsFetch_1 = require("../../utils/awsFetch");
/*
    Regexp will match for example:
        ${Region}
        ${Outputs.SomeStackOutput}
    
    But it can be escaped:
        \${Region} won't result in a match
*/
const replaceVariables = (value, { target, outputs, stackName }) => Array.from(value.matchAll(/(?<!\\)\${((.(?!\$)(?!\{))*)}/g)).reduce((val, match) => {
    var _a;
    const variableExpression = match[0];
    const variableName = match[1];
    if (variableName.startsWith('Outputs.')) {
        const outputName = variableName.replace('Outputs.', '');
        if (outputName in outputs) {
            return val.replace(variableExpression, outputs[outputName]);
        }
    }
    else if (variableName === 'Region') {
        return val.replace(variableExpression, target.region);
    }
    else if (variableName === 'StackId') {
        return val.replace(variableExpression, target.arn);
    }
    else if (variableName === 'StackName') {
        return val.replace(variableExpression, stackName);
    }
    else if (variableName === 'AccountId') {
        return val.replace(variableExpression, ((_a = target.arn.match(/:([0-9]{12}):/)) !== null && _a !== void 0 ? _a : [])[1]);
    }
    return val;
}, value);
const loadEntitiesFromCloudFormation = async (target) => {
    var _a, _b, _c, _d;
    const cloudFormation = new aws_sdk_1.CloudFormation({
        credentials: new aws_sdk_1.SharedIniFileCredentials({
            profile: target.profile
        }),
        region: target.region
    });
    // Load template - Metadata
    const template = await (0, awsFetch_1.awsFetch)(async () => cloudFormation.getTemplateSummary({ StackName: target.arn }).promise());
    const metadata = JSON.parse((_a = template.Metadata) !== null && _a !== void 0 ? _a : '{}');
    const rawEntities = (_c = (_b = metadata === null || metadata === void 0 ? void 0 : metadata.Backstage) === null || _b === void 0 ? void 0 : _b.Entities) !== null && _c !== void 0 ? _c : [];
    // Load stack info - Outputs
    const stacks = (await (0, awsFetch_1.awsFetch)(async () => cloudFormation.describeStacks({ StackName: target.arn }).promise())).Stacks;
    if (typeof stacks === 'undefined' || stacks.length === 0) {
        throw new Error(`Stack "${target.arn}" not found.`);
    }
    const outputs = ((_d = stacks[0].Outputs) !== null && _d !== void 0 ? _d : []).reduce((acc, { OutputKey, OutputValue }) => {
        if (typeof OutputKey !== 'undefined' &&
            typeof OutputValue !== 'undefined') {
            acc[OutputKey] = OutputValue;
        }
        return acc;
    }, {});
    const processedEntities = (0, find_and_replace_anything_1.findAndReplaceIf)(rawEntities, (value) => {
        if (typeof value !== 'string') {
            return value;
        }
        return replaceVariables(value, {
            target,
            outputs,
            stackName: stacks[0].StackName
        });
    }, { checkArrayValues: true });
    return processedEntities;
};
exports.loadEntitiesFromCloudFormation = loadEntitiesFromCloudFormation;
//# sourceMappingURL=loadEntities.js.map