"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.awsFetch = void 0;
const isAWSError = (error) => typeof error === 'object' &&
    error !== null &&
    'code' in error &&
    'retryable' in error;
async function awsFetch(fetch) {
    try {
        return await fetch();
    }
    catch (err) {
        if (isAWSError(err) &&
            err.code === 'Throttling' &&
            err.retryable === true) {
            return new Promise((resolve) => {
                setTimeout(() => resolve(awsFetch(fetch)), Math.random() * 3000 + 2000 // 2 to 5 seconds cooldown
                );
            });
        }
        throw err;
    }
}
exports.awsFetch = awsFetch;
//# sourceMappingURL=awsFetch.js.map